datanommer.commands
===================

.. split here

This package contains the console commands for datanommer, including::

 - datanommer-create-db
 - datanommer-dump
 - datanommer-stats

Datanommer is a storage consumer for the Fedora Infrastructure Message Bus
(fedmsg).  It is comprised of a `fedmsg <http://fedmsg.com>`_ consumer that
stuffs every message into a sqlalchemy database.
